@@ -1,11 +1,13 @@
 from covid_cloud.cli.utils import assert_config
 from covid_cloud.client import *
+from covid_cloud.cli.auth.utils import assert_token
 
 
 @click.group()
 @click.pass_context
 def files(ctx):
     assert_config(ctx, 'drs-url')
+    assert_token(ctx)
 
 
 @files.command()
