@@ -4,9 +4,8 @@ import threading
 import os
 from typing import Optional
 
-from .constants import *
+from covid_cloud.constants import *
 from requests.exceptions import HTTPError
-from search_python_client.search import DrsClient
 from covid_cloud.client.utils import get_drs_client
 
 
@@ -20,6 +19,7 @@ def download_file(drs_url, url, output_dir, oauth_token: Optional[str] = None):
     http = urllib3.PoolManager()
     chunk_size = 1024
     download_url = url
+    signed_access_ids = ['az-blobstore-signed']
 
     object_id = url.split('/')[-1]
     if is_drs_url(url):
@@ -36,12 +36,19 @@ def download_file(drs_url, url, output_dir, oauth_token: Optional[str] = None):
 
         if "access_methods" in object_info.keys():
             for access_method in object_info["access_methods"][0]:
-                if access_method['type'] == 'access_id':
-                    click.echo("found access_id @ access_method level")
+                if access_method.get('access_id', None):
+                    if access_method['access_id'] in signed_access_ids:
+                        click.echo("found signed access_id @ access_method level")
+                        try:
+                            object_access = drs_client.get_object_access(object_id, access_method['access_id'])
+                        except HTTPError as e:
+                            click.echo(e)
+                            return
+                        download_url = object_access['url']
+                        break
+
                 # if we have an https, use that
                 if access_method['type'] == 'https':
-                    if 'access_id' in access_method['access_url'].keys():
-                        click.echo("found access_id @ access_url level")
                     download_url = access_method['access_url']['url']
                     break
         else:
